--------------------------------------------------------------------------------
--
-- Title       :
-- Design      :
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : DoubleClock.vhd
-- Generated   : Jun 23  2020
--------------------------------------------------------------------------------
-- Description : Double clock design compare
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 23/06/20	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee ;

use ieee.std_logic_1164.all ;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity DoubleClock  is
port
(
 ClockIn ,        																															-- General Clock
 nClockIn ,        																															-- General not Clock
 nResetIn,          																														-- General Reset active High
 DataInValidIn           																												-- Input Data vavid
 										: in std_logic;
 DataIn
 										: in std_logic_vector(7 downto 0);
 sClockDataOut,            																											-- Data Generated by single Clock
 dClockDataOut             																											-- Data Generated by double Clock
                    : out std_logic_vector(7 downto 0)
);
end DoubleClock;

architecture  ArchDoubleClock of DoubleClock is
type     ClockData is array(0 to 7) of std_logic_vector(7 downto 0) ;
signal   sClockData : ClockData;

type     Clock_Data is array(0 to 3) of std_logic_vector(7 downto 0) ;
signal   dClockData,ndClockData : Clock_Data ;

signal DataValid : std_logic_vector(7 downto 0) := (others => '0');

begin

 DataValid_Process:
process (ClockIn )
begin
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
	  DataValid  <= (others => '0');
	 when others =>
	  DataValid(0) <= DataInValidIn;
		DataValid(7 downto 1) <= DataValid(6 downto 0);
	end case;
 end if;
end process  DataValid_Process;

 sClockData_Process:
process (ClockIn )
begin
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
		for i in 7 downto 0 loop
		 sClockData(i) <= (others => '0');
		end loop ;
 	 when others =>
	  sClockData(0) 					<= DataIn;
		for i in 7 downto 1 loop
	   sClockData(i) 	<= sClockData(i-1) + 3;
		end loop ;
	end case;
 end if;
end process  sClockData_Process;


 sClockDataOut_Process:
process (ClockIn )
begin
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
	  sClockDataOut <= (others => '0');
	 when others =>
		case DataValid(7) is
		 when '1' =>
		  sClockDataOut <= sClockData(7);
		 when others =>
		  sClockDataOut <= (others => '0');
		end case;
	end case;
 end if;
end process  sClockDataOut_Process;

 ndClockData_Process:
process (nClockIn)
begin
 if(nClockIn'event and nClockIn = '1') then
	case nResetIn is
	 when '0' =>
		for i in 3 downto 0 loop
		 ndClockData(i) <= (others => '0');
		end loop ;
	 when others =>
 	  ndClockData(0) <= DataIn;
		for i in 3 downto 1 loop
	   ndClockData(i) <= dClockData(i-1) + 3;
		end loop ;
  end case;
 end if;
end process  ndClockData_Process;

 dClockData_Process:
process (ClockIn)
begin
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
		for i in 3 downto 0 loop
		 dClockData(i) <= (others => '0');
		end loop ;
	 when others =>
		for i in 3 downto 0 loop
	   dClockData(i) <= ndClockData(i) + 3;
		end loop ;
  end case;
 end if;
end process  dClockData_Process;

 dClockDataOut_Process:
process (ClockIn )
begin
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
	  dClockDataOut <= (others => '0');
	 when others =>
		case DataValid(3) is
		 when '1' =>
		  dClockDataOut <= dClockData(3);
		 when others =>
		  dClockDataOut <= (others => '0');
		end case;
	end case;
 end if;
end process  dClockDataOut_Process;

end ArchDoubleClock;
