--------------------------------------------------------------------------------
--
-- Title       :
-- Design      :
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : DoubleClock_Tb.vhd
-- Generated   : Jun 23  2020
--------------------------------------------------------------------------------
-- Description :  Double clock design compare test bench
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 23/06/20	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee ;

use ieee.std_logic_1164.all ;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity DoubleClock_Tb is

end DoubleClock_Tb;

architecture  ArchDoubleClock_Tb of DoubleClock_Tb is

signal Clock    ,   																 		 		 		 		 		 				-- Clock
			 DataInValid     																													-- Input Data vavid
										: std_logic := '0';
signal nReset,          																												-- General Reset active Low
			 nClock       																 		 		 		 		 		 				-- not Clock
										: std_logic := '1';
 signal sClockData,            																									-- Data Generated by single Clock
  			dClockData,             																								-- Data Generated by double Clock
				Data                                                    								-- Data for test
                    : std_logic_vector(7 downto 0) := (others => '0');

begin
Clock 		<= not Clock after 10 nS;     																				-- Clock 50.000 MHz
nClock 		<= not Clock ;     																										-- not Clock 50.000 MHz
nReset		<= '1','0' after 50 nS,'1' after 100 nS;         											-- General Reset active Low

DoubleClock_UUT :  entity work.DoubleClock
port map
(
 ClockIn 						=> Clock,        																						-- General Clock
 nClockIn						=> nClock,        																					-- General not Clock
 nResetIn           => nReset,																									-- General Reset active High
 DataInValidIn      => DataInValid,     																				-- Input Data vavid
 DataIn             => Data,                                                    -- Data for test
 sClockDataOut      => sClockData,            																	-- Data Generated by single Clock
 dClockDataOut      => dClockData             																	-- Data Generated by double Clock
);

 TestProcess:
process
begin
Data  				<= (others => '0');                                        								-- Data for test
DataInValid 	<=  '0';     																											-- Input Data vavid
wait for	150 nS;

wait until Clock'event and Clock = '0';
DataInValid 	<=  '1';     																											-- Input Data vavid
Data  <= X"04";
wait until Clock'event and Clock = '0';
DataInValid 	<=  '0';     																											-- Input Data vavid
Data  <= (others => '0');                                        								-- Data for test
wait for	150 nS;
wait until Clock'event and Clock = '0';
wait until Clock'event and Clock = '0';
wait until Clock'event and Clock = '0';
wait until Clock'event and Clock = '0';
wait until Clock'event and Clock = '0';
wait until Clock'event and Clock = '0';
wait until Clock'event and Clock = '0';
wait until Clock'event and Clock = '0';
DataInValid 	<=  '1';     																											-- Input Data vavid
Data  <= X"08";
wait until Clock'event and Clock = '0';
DataInValid 	<=  '0';     																											-- Input Data vavid
Data  <= (others => '0');                                        								-- Data for test

wait;
end process  TestProcess;


end ArchDoubleClock_Tb;
